#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#


# default value in case of no qubes-builder's one

Name:		qubes-gui-agent
Version:	4.0.23
Release:	1%{dist}
Summary:	The Qubes GUI Agent for AppVMs

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org


%define pa_ver %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1)

BuildRequires:	gcc
BuildRequires:	libX11-devel
BuildRequires:	libXcomposite-devel
BuildRequires:	libXdamage-devel
BuildRequires:	libXt-devel
BuildRequires:	libtool-ltdl-devel
BuildRequires:	pulseaudio-libs-devel >= 0.9.21, pulseaudio-libs-devel <= 12.2
BuildRequires:	xorg-x11-server-devel
BuildRequires:	pam-devel
BuildRequires:	qubes-libvchan-xen-devel
BuildRequires:	qubes-gui-common-devel >= 3.2.0
BuildRequires:	qubes-db-devel
Requires:	Xorg %(xserver-sdk-abi-requires ansic)
Requires:	Xorg %(xserver-sdk-abi-requires videodrv)
Requires:	qubes-core-vm >= 3.0.14
Requires:	xorg-x11-xinit
Requires:	qubes-libvchan-xen
Requires:	python%{python3_pkgversion}-xcffib
Requires:   xorg-x11-server-Xorg
Provides:   qubes-gui-vm = %{version}-%{release}
Obsoletes:  qubes-gui-vm < 4.0.0

Source0: %{name}-%{version}.tar.gz

%package -n pulseaudio-qubes
Summary: Audio support for Qubes VM
# The vchan sink needs .h files from pulseaudio sources
# that are not exported by any *-devel packages; thus they are internal and
# possible to change across version. They are copied to gui git.
# It is possible that our code will work fine with any later pulseaudio
# version; but this needs to be verified for each pulseaudio version.
Requires:	pulseaudio = %{pa_ver}
Conflicts:  qubes-gui-vm < 4.0.0

%description -n pulseaudio-qubes
Pulseaudio module to enable sound support in Qubes VM

%package xfce
Summary: XFCE desktop support for Qubes VM

%description xfce
XFCE desktop support for Qubes VM

%description
The Qubes GUI agent that needs to be installed in VM in order to provide the
Qubes fancy GUI.

%prep
%setup -q

rm -f pulse/pulsecore
ln -s pulsecore-%{pa_ver} pulse/pulsecore

%build
%{?set_build_flags}
#make clean
make BACKEND_VMM=xen appvm

%install
rm -rf $RPM_BUILD_ROOT
make install install-xfce DESTDIR=$RPM_BUILD_ROOT \
                     LIBDIR=%{_libdir} \
                     DATADIR=%{_datadir} \
                     PA_VER=%{pa_ver}

%post
if [ -x /bin/systemctl ] && readlink /sbin/init | grep -q systemd; then
    /bin/systemctl enable qubes-gui-agent.service 2> /dev/null
else
    chkconfig qubes-gui-agent on
fi

%post -n pulseaudio-qubes

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%preun
if [ "$1" = 0 ] ; then
	chkconfig qubes-gui-agent off
    [ -x /bin/systemctl ] && /bin/systemctl disable qubes-gui-agent.service
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi

%posttrans
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

%triggerin -n pulseaudio-qubes -- pulseaudio-libs

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}


%files
%defattr(-,root,root,-)
/usr/bin/qubes-gui
/usr/bin/qubes-gui-runuser
/usr/bin/qubes-session
/usr/bin/qubes-run-xorg
/usr/bin/qubes-change-keyboard-layout
/usr/bin/qubes-set-monitor-layout
%{_libdir}/xorg/modules/drivers/qubes_drv.so
%{_libdir}/xorg/modules/drivers/dummyqbs_drv.so
%attr(0644,root,root) /etc/X11/xorg-qubes.conf.template
/etc/init.d/qubes-gui-agent
/etc/profile.d/qubes-gui.sh
/etc/profile.d/qubes-gui.csh
/etc/profile.d/qubes-session.sh
%config /etc/pam.d/qubes-gui-agent
%config /etc/security/limits.d/90-qubes-gui.conf
%config /etc/xdg/Trolltech.conf
/etc/X11/xinit/xinitrc.d/qubes-keymap.sh
/etc/X11/xinit/xinitrc.d/20qt-x11-no-mitshm.sh
/etc/X11/xinit/xinitrc.d/20qt-gnome-desktop-session-id.sh
/etc/qubes-rpc/qubes.SetMonitorLayout
%config /etc/sysconfig/desktop
/etc/sysconfig/modules/qubes-u2mfn.modules
/lib/systemd/system/qubes-gui-agent.service
/lib/udev/rules.d/70-master-of-seat.rules
/usr/lib/modules-load.d/qubes-gui.conf
/usr/lib/tmpfiles.d/qubes-session.conf
/usr/lib/sysctl.d/30-qubes-gui-agent.conf
%{_datadir}/glib-2.0/schemas/20_qubes-gui-vm.gschema.override
/usr/lib/qubes/icon-sender
/etc/xdg/autostart/qubes-icon-sender.desktop
%dir /var/log/qubes

%files -n pulseaudio-qubes
/usr/lib/tmpfiles.d/qubes-pulseaudio.conf
/etc/pulse/qubes-default.pa
/usr/bin/start-pulseaudio-with-vchan
%{_libdir}/pulse-%{pa_ver}/modules/module-vchan-sink.so
/etc/xdg/autostart/qubes-pulseaudio.desktop

%files xfce
/etc/X11/xinit/xinitrc.d/50-xfce-desktop.sh

%changelog
* Fri Apr 05 2019 Qubes OS Team <qubes-devel@groups.google.com>
- For complete changelog see: https://github.com/QubesOS/qubes-gui-agent-linux

* Fri Apr 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7a3bb89
- version 4.0.23

* Fri Apr 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ad8fd1a
- Convert qubes-change-keyboard-layout to python3

* Wed Mar 20 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 18a0b9f
- version 4.0.22

* Wed Mar 20 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5478890
- video-dummy: fix off by one error in memory size check

* Fri Mar 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8b8b883
- version 4.0.21

* Fri Mar 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8c4735d
- Indentation fix

* Fri Mar 01 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 86b5b8d
- Fix GCC9 warning about size in strncpy

* Fri Jan 18 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0005614
- Drop /etc/X11/Xwrapper.config

* Fri Jan 11 2019 Olivier MEDOC <o_medoc@yahoo.fr> - d456f65
- archlinux: switch to using icon-sender with python3

* Fri Jan 04 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bc54e44
- version 4.0.20

* Sun Dec 23 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0104aaf
- Merge remote-tracking branch 'qubesos/pr/59'

* Sat Dec 22 2018 Frédéric Pierret (fepitre) <frederic.epitre@orange.fr> - e694db7
- spec: fix missing abi version requirement

* Tue Nov 27 2018 Olivier MEDOC <o_medoc@yahoo.fr> - 01ea25f
- fix install path to follow archlinux packaging guidelines

* Wed Nov 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9f15169
- version 4.0.19

* Wed Nov 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1308652
- Merge branch 'logind'

* Fri Nov 16 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aca4099
- vmside: cleanup calling qubes-run-xorg, terminate it on service stop

* Fri Nov 16 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - db9e515
- qubes-run-xorg: fix one more place with hardcoded 'user'

* Fri Nov 16 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6425ba2
- Fix X11 session registration in logind

* Tue Nov 13 2018 Wojtek Porczyk <woju@invisiblethingslab.com> - d222e16
- qubes-run-xorg: add configurable videoram overhead

* Wed Oct 31 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e9b972e
- Fix qubes-keymap script permissions

* Mon Oct 29 2018 Duncan X. Simpson <virtualdxs@gmail.com> - 46aec51
- Bump xorg-server version

* Mon Oct 29 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0abccf0
- version 4.0.18

* Sat Oct 27 2018 Duncan X. Simpson <virtualdxs@gmail.com> - 4efb79d
- Fix python-xcffib dependency

* Tue Oct 23 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 974b13d
- Merge branch 'composite-automatic'

* Tue Oct 23 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3187ffb
- gui-agent: switch to automatic composition mode, fix in-vm screenshots

* Sat Oct 20 2018 unman <unman@thirdeyesecurity.org> - 3c9f6e6
- Add epoch for pulseaudio-qubes requirements in Ubuntu builds

* Tue Oct 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b6de187
- version 4.0.17

* Tue Oct 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2b6ed15
- xf86-video-dummy: indent with spaces not tabs

* Tue Oct 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 19a41f5
- xf86-video-dummy: drop unused variables

* Tue Oct 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 18ac775
- archlinux: update dependencies

* Tue Oct 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5d044c5
- window-icon-updater: drop python-xcb support

* Tue Oct 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bf1cf9f
- window-icon-updater: make it work with python3

* Tue Oct 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 87122bb
- Merge remote-tracking branch 'origin/pr/51'

* Thu Sep 20 2018 fepitre <frederic.epitre@orange.fr> - 61589cf
- Update to python3-xcffib

* Sun Sep 16 2018 fepitre <frederic.epitre@orange.fr> - 045f19e
- travis: add fc29

* Wed Sep 12 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 198077e
- version 4.0.16

* Wed Sep 12 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d5bbb59
- debian: update standard version, minor fix

* Wed Sep 12 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4562a25
- debian: ignore pulseaudio-related lintian warnings

* Wed Sep 12 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 63f7a2f
- debian: remove manual systemctl call

* Wed Sep 12 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d003636
- Make sourced files not executable

* Wed Sep 12 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c461fb7
- Remove generated/useless files

* Tue Sep 11 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c1c4fb7
- Drop .sh from /usr/bin/qubes-run-xorg.sh

* Sun Sep 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d8894c2
- debian: bind to specific pulseaudio version

* Sun Sep 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 675260c
- pulse: update module for pulseaudio 12.0

* Mon Aug 20 2018 Olivier MEDOC <o_medoc@yahoo.fr> - 246fe74
- archlinux: bump xorg-server version

* Sat Aug 04 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cfa724d
- version 4.0.15

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f45235b
- rpm: use build flags provided by the distribution

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a28452f
- Allow overriding CC variable - choose another compiler

* Fri Jul 27 2018 Jean-Philippe Ouellet <jpo@vt.edu> - 4e9a311
- Bump Arch pulseaudio to 12.2 too

* Fri Jul 27 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 560ed7d
- version 4.0.14

